/**
 * {}
 * @author yutent<yutent.io@gmail.com>
 * @date 2023/03/21 16:14:10
 */

import { css, html, Component } from 'wkit'

class Badge extends Component {
  static props = {
    value: 0,
    max: 0
  }

  get #value() {
    if (this.value > 0) {
      if (this.max > 0) {
        if (this.value > this.max) {
          return this.max + '+'
        }
      }
      return this.value
    }
    return ''
  }

  static styles = [
    css`
      :host {
        display: inline-flex;
      }

      .container {
        position: relative;
      }

      .dot {
        position: absolute;
        z-index: 9;
        left: calc(100% - 9px);
        top: -8px;
        display: inline-flex;
        justify-content: center;
        align-items: center;
        min-width: 14px;
        height: 14px;
        padding: 0 4px;
        border-radius: 10px;
        background: var(--color-red-1);
        -webkit-user-select: none;
        user-select: none;
      }

      .num {
        line-height: 12px;
        font-size: 12px;
        font-style: normal;
        white-space: nowrap;
        font-family: Tahoma, Verdana, Helvetica, Arial, sans-serif;
        color: #fff;
      }

      :host([hidden-value]) .dot {
        .num {
          display: none;
        }
      }
    `,

    //配色
    css`
      $colors: (
        info: 'blue',
        success: 'teal',
        warning: 'orange'
      );

      @loop $t, $c in $colors {
        :host([type='#{$t}']) {
          .dot {
            background-color: var(--color-#{$c}-1);
          }
        }
      }
    `
  ]

  render() {
    return html`
      <main class="container">
        <slot></slot>
        <span class="dot"><i class="num">${this.#value}</i></span>
      </main>
    `
  }
}

Badge.reg('badge')
